/*
 * Copyright (C) LEE Ventus - All Rights Reserved
 * Unauthorised copying of this file, via any medium is strictly prohibited
 * Proprietary and confidential
 */
#include "controlMethods.h"

typedef enum
{
    OFF,
    PID_CTRL,
    BANG_BANG_CTRL
} controlState;

static controlState state = OFF;

// PID control variables
static controlMethods_pidSettings pidSetup;
static float integral;
static float prevError;

// Bang bang control variables
static controlMethods_bangBangSettings bbSetup;
static bool isUpperControlValue;

static float pidControl();
static float bangBangControl();


void controlMethods_startPID(controlMethods_pidSettings pidSettings,
                             bool resetITermAccumulator)
{
    pidSetup = pidSettings;

    if(resetITermAccumulator)
    {
        integral = 0;
        prevError = 0;
    }

    state = PID_CTRL;
}

void controlMethods_startBangBang(controlMethods_bangBangSettings bbSettings)
{
    bbSetup = bbSettings;
    isUpperControlValue = false;

    state = BANG_BANG_CTRL;
}

float controlMethods_tick()
{
    switch(state)
    {
        case OFF:
            return 0;

        case PID_CTRL:
            return pidControl();

        case BANG_BANG_CTRL:
            return bangBangControl();

        default:
        	return 0;
    }
}

static float pidControl()
{
    // Run PID tick
    float error = pidSetup.getSetPoint() - pidSetup.getInputValue();

    // Calculate p value
    float p = pidSetup.proportionalTerm * error;

    integral += pidSetup.integralTerm * error / 1000.0;

    if(integral > pidSetup.integralMax)
    {
        integral = pidSetup.integralMax;
    }
    else if(integral < pidSetup.integralMin)
    {
        integral = pidSetup.integralMin;
    }

    // Calculate d value
    float d = (prevError - error) * pidSetup.differentialTerm;

    // Store the error for next time
    prevError = error;

    // Return sum of P I and D
    return p + integral + d;
}

static float bangBangControl()
{
    float inputValue = bbSetup.getInputValue();

    //Determine bang bang state
    if(inputValue < bbSetup.lowerThresh)
    {
        isUpperControlValue = false;
    }
    else if(inputValue > bbSetup.upperThresh)
    {
        isUpperControlValue = true;
    }

    //Set target control value
    if(isUpperControlValue)
    {
        return bbSetup.upperControlValue;
    }
    else
    {
        return bbSetup.lowerControlValue;
    }
}
