/*
 * Copyright (C) LEE Ventus - All Rights Reserved
 * Unauthorised copying of this file, via any medium is strictly prohibited
 * Proprietary and confidential
 */


#ifndef GPIOHANDLER_H
#define GPIOHANDLER_H

#define PIN_STATE_FOR_CONST_ON (-1)
#define PIN_STATE_FOR_CONST_OFF (0)

#include <stdint.h>
#include <stdbool.h>

#include "Settings.h"


typedef struct {
	// the settings that the GPIO will interact with
	const setting_int* pin_state_setting;
	const setting_int* pin_pulse_duration_setting;
	const setting_int* pin_pulse_period_setting;

	// internal variables
	GPIO_mode pin_mode;
	bool pin_default_state;
	int16_t pin_pulse_counter;
	int16_t pin_period_counter;
	int16_t pin_period;
	int16_t pin_duration;

	// function pointers to interact with the HAL GPIO functions
	void (*set_Output_GPIO)(bool state);
	bool (*get_Input_GPIO)(void);
	// function pointers to interact with the HAL TIM functions
	void (*startTimPulse)(uint8_t num_pulses, uint16_t period, uint16_t duration);
	void (*setTimControlMode)(uint32_t mode);
} gpio_instance;

// Called once to give the GPIO Handler the hardware states for Timer Counter, as they are the same for all TC
void GPIO_Handler_set_TC_states(uint32_t set_TC_PWMMode1, uint32_t set_TC_PWMMode2, uint32_t set_TC_ForceActive, uint32_t set_TC_ForceInactive);

// Called to setup the GPIO_Handler
void GPIO_Handler_init(gpio_instance* pin, GPIO_mode GPIO_mode_val, bool pin_default_state_val);

// Should be called each tick (typically 1ms)
void GPIO_Handler_tick(gpio_instance* pin);


//helper function
bool isInput(gpio_instance* pin);

//helper function
bool isHighSpeed(gpio_instance* pin);

#endif
