/*
 * Copyright (C) LEE Ventus - All Rights Reserved
 * Unauthorised copying of this file, via any medium is strictly prohibited
 * Proprietary and confidential
 */
#include "i2cHoneywellMPR.h"

typedef enum
{
    IDLE,
    WRITING,
    WRITTEN,
    READING
} deviceState;

static uint8_t MPR_POWERED = 1 << 6;
static uint8_t MPR_BUSY = 1 << 5;
static uint8_t MPR_ERROR = 1 << 2;
static uint8_t MPR_MATH_SATURATION = 1;

static deviceState state;
static i2c_device device;
static volatile uint8_t buf[4];
static uint32_t counts = 0;

static i2c_request service();
static uint16_t writeCompleteCallback(bool success);
static uint16_t readCompleteCallback(bool success);

i2c_device honeywellMPR_getDevice()
{
    state = IDLE;
    counts = 0;

    device.i2cAddr = HONEYWELL_MPR_I2C_ADDR;
    device.serviceI2CDevice = service;

    return device;
}

uint32_t honeywellMPR_getCounts()
{
    return counts;
}

static i2c_request service()
{
    i2c_request request;

    switch(state)
    {
        case WRITTEN:
            request.type = I2C_READ;
            request.count = 4;
            request.buf = buf;
            request.requestCompleteCallback = readCompleteCallback;

            state = READING;
            break;

        default:
            buf[0] = 0xAA;
            buf[1] = 0;
            buf[2] = 0;

            request.type = I2C_WRITE;
            request.count = 3;
            request.buf = buf;
            request.requestCompleteCallback = writeCompleteCallback;

            state = WRITING;
            break;
    }

    return request;
}

static uint16_t writeCompleteCallback(bool success)
{
    if(success)
    {
        state = WRITTEN;
        return 7;
    }
    else
    {
        state = IDLE;
        return 0;
    }
}

static uint16_t readCompleteCallback(bool success)
{
    if(success && buf[0] == MPR_POWERED)
    {
        counts = 0;
        counts += buf[1] << 16;
        counts += buf[2] << 8;
        counts += buf[3];

        state = IDLE;
    }
    else if(!success | buf[0] & MPR_BUSY)
    {
        state = WRITTEN;  // Force another read
    }
    else
    {
        state = IDLE;  // Start from beginning
    }

    return 0;
}
