/*
 * Copyright (C) LEE Ventus - All Rights Reserved
 * Unauthorised copying of this file, via any medium is strictly prohibited
 * Proprietary and confidential
 */
#ifndef I2CHONEYWELLMPR_H
#define I2CHONEYWELLMPR_H

#include "i2cMasterHandler.h"

i2c_device honeywellMPR_getDevice();

uint32_t honeywellMPR_getCounts();



//automatic defines to keep track of which pressure sensor we have
//if the sensor name contains a dot . replace it with an underscore _
/*example
 * for sensor MPRLS0025PA00001A
 * #define HONEYWELL_PRESSURE_RANGE_0025PA
 * #define HONEYWELL_SECOND_TO_LAST_DIGIT_1
 * #define HONEYWELL_LAST_DIGIT_A
 *
 *
 * for sensor MPRLS02.5BA00002C
 * #define HONEYWELL_PRESSURE_RANGE_02_5BA
 * #define HONEYWELL_SECOND_TO_LAST_DIGIT_2
 * #define HONEYWELL_LAST_DIGIT_C
 *
 */
#if defined(MPM_PUMP_DRIVER)
//TODO - add MPM pressure sensor config

#elif defined(SINGLE_PUMP_MODULE)
	#define HONEYWELL_PRESSURE_RANGE_0025PA
	#define HONEYWELL_SECOND_TO_LAST_DIGIT_1
	#define HONEYWELL_LAST_DIGIT_A
#elif defined(COST_OPTIMISED_DRIVER)
	#define HONEYWELL_PRESSURE_RANGE_0025PA
	#define HONEYWELL_SECOND_TO_LAST_DIGIT_1
	#define HONEYWELL_LAST_DIGIT_A
#else
// just need something so we compile
	#define HONEYWELL_PRESSURE_RANGE_0025PA
	#define HONEYWELL_SECOND_TO_LAST_DIGIT_1
	#define HONEYWELL_LAST_DIGIT_A
#endif



// below is the automated (brute force) set of parameters for all honeywell pressure sensors
// DO NOT EDIT

#if defined(HONEYWELL_SECOND_TO_LAST_DIGIT_0)
	#define HONEYWELL_MPR_I2C_ADDR 0x08
#endif
#if defined(HONEYWELL_SECOND_TO_LAST_DIGIT_1)
	#define HONEYWELL_MPR_I2C_ADDR 0x18
#endif
#if defined(HONEYWELL_SECOND_TO_LAST_DIGIT_2)
	#define HONEYWELL_MPR_I2C_ADDR 0x28
#endif
#if defined(HONEYWELL_SECOND_TO_LAST_DIGIT_3)
	#define HONEYWELL_MPR_I2C_ADDR 0x38
#endif
#if defined(HONEYWELL_SECOND_TO_LAST_DIGIT_4)
	#define HONEYWELL_MPR_I2C_ADDR 0x48
#endif
#if defined(HONEYWELL_SECOND_TO_LAST_DIGIT_5)
	#define HONEYWELL_MPR_I2C_ADDR 0x58
#endif
#if defined(HONEYWELL_SECOND_TO_LAST_DIGIT_6)
	#define HONEYWELL_MPR_I2C_ADDR 0x68
#endif
#if defined(HONEYWELL_SECOND_TO_LAST_DIGIT_7)
	#define HONEYWELL_MPR_I2C_ADDR 0x78
#endif




#if defined(HONEYWELL_LAST_DIGIT_A)
         #define HONEYWELL_MPR_UBAR_OFFSET 1677722
#endif
//gain = 19.073486
 #if defined(HONEYWELL_PRESSURE_RANGE_0001BA) && defined(HONEYWELL_LAST_DIGIT_A)
         #define HONEYWELL_MPR_UBAR_SCALING 9766
         #define HONEYWELL_MPR_UBAR_SHIFT 9
#endif
//gain = 30.517578
 #if defined(HONEYWELL_PRESSURE_RANGE_01_6BA) && defined(HONEYWELL_LAST_DIGIT_A)
         #define HONEYWELL_MPR_UBAR_SCALING 15625
         #define HONEYWELL_MPR_UBAR_SHIFT 9
#endif
//gain = 47.683716
 #if defined(HONEYWELL_PRESSURE_RANGE_02_5BA) && defined(HONEYWELL_LAST_DIGIT_A)
         #define HONEYWELL_MPR_UBAR_SCALING 24414
         #define HONEYWELL_MPR_UBAR_SHIFT 9
#endif
//gain = 1.144409
 #if defined(HONEYWELL_PRESSURE_RANGE_0060MG) && defined(HONEYWELL_LAST_DIGIT_A)
         #define HONEYWELL_MPR_UBAR_SCALING 586
         #define HONEYWELL_MPR_UBAR_SHIFT 9
         #define GAUGE_PRESSURE
#endif
//gain = 1.907349
 #if defined(HONEYWELL_PRESSURE_RANGE_0100MG) && defined(HONEYWELL_LAST_DIGIT_A)
         #define HONEYWELL_MPR_UBAR_SCALING 977
         #define HONEYWELL_MPR_UBAR_SHIFT 9
         #define GAUGE_PRESSURE
#endif
//gain = 3.051758
 #if defined(HONEYWELL_PRESSURE_RANGE_0160MG) && defined(HONEYWELL_LAST_DIGIT_A)
         #define HONEYWELL_MPR_UBAR_SCALING 1563
         #define HONEYWELL_MPR_UBAR_SHIFT 9
         #define GAUGE_PRESSURE
#endif
//gain = 4.768372
 #if defined(HONEYWELL_PRESSURE_RANGE_0250MG) && defined(HONEYWELL_LAST_DIGIT_A)
         #define HONEYWELL_MPR_UBAR_SCALING 2441
         #define HONEYWELL_MPR_UBAR_SHIFT 9
         #define GAUGE_PRESSURE
#endif
//gain = 7.629395
 #if defined(HONEYWELL_PRESSURE_RANGE_0400MG) && defined(HONEYWELL_LAST_DIGIT_A)
         #define HONEYWELL_MPR_UBAR_SCALING 3906
         #define HONEYWELL_MPR_UBAR_SHIFT 9
         #define GAUGE_PRESSURE
#endif
//gain = 11.444092
 #if defined(HONEYWELL_PRESSURE_RANGE_0600MG) && defined(HONEYWELL_LAST_DIGIT_A)
         #define HONEYWELL_MPR_UBAR_SCALING 5859
         #define HONEYWELL_MPR_UBAR_SHIFT 9
         #define GAUGE_PRESSURE
#endif
//gain = 19.073486
 #if defined(HONEYWELL_PRESSURE_RANGE_0001BG) && defined(HONEYWELL_LAST_DIGIT_A)
         #define HONEYWELL_MPR_UBAR_SCALING 9766
         #define HONEYWELL_MPR_UBAR_SHIFT 9
         #define GAUGE_PRESSURE
#endif
//gain = 30.517578
 #if defined(HONEYWELL_PRESSURE_RANGE_01_6BG) && defined(HONEYWELL_LAST_DIGIT_A)
         #define HONEYWELL_MPR_UBAR_SCALING 15625
         #define HONEYWELL_MPR_UBAR_SHIFT 9
         #define GAUGE_PRESSURE
#endif
//gain = 47.683716
 #if defined(HONEYWELL_PRESSURE_RANGE_02_5BG) && defined(HONEYWELL_LAST_DIGIT_A)
         #define HONEYWELL_MPR_UBAR_SCALING 24414
         #define HONEYWELL_MPR_UBAR_SHIFT 9
         #define GAUGE_PRESSURE
#endif
//gain = 19.073486
 #if defined(HONEYWELL_PRESSURE_RANGE_0100KA) && defined(HONEYWELL_LAST_DIGIT_A)
         #define HONEYWELL_MPR_UBAR_SCALING 9766
         #define HONEYWELL_MPR_UBAR_SHIFT 9
#endif
//gain = 30.517578
 #if defined(HONEYWELL_PRESSURE_RANGE_0160KA) && defined(HONEYWELL_LAST_DIGIT_A)
         #define HONEYWELL_MPR_UBAR_SCALING 15625
         #define HONEYWELL_MPR_UBAR_SHIFT 9
#endif
//gain = 47.683716
 #if defined(HONEYWELL_PRESSURE_RANGE_0250KA) && defined(HONEYWELL_LAST_DIGIT_A)
         #define HONEYWELL_MPR_UBAR_SCALING 24414
         #define HONEYWELL_MPR_UBAR_SHIFT 9
#endif
//gain = 1.144409
 #if defined(HONEYWELL_PRESSURE_RANGE_0006KG) && defined(HONEYWELL_LAST_DIGIT_A)
         #define HONEYWELL_MPR_UBAR_SCALING 586
         #define HONEYWELL_MPR_UBAR_SHIFT 9
         #define GAUGE_PRESSURE
#endif
//gain = 1.907349
 #if defined(HONEYWELL_PRESSURE_RANGE_0010KG) && defined(HONEYWELL_LAST_DIGIT_A)
         #define HONEYWELL_MPR_UBAR_SCALING 977
         #define HONEYWELL_MPR_UBAR_SHIFT 9
         #define GAUGE_PRESSURE
#endif
//gain = 3.051758
 #if defined(HONEYWELL_PRESSURE_RANGE_0016KG) && defined(HONEYWELL_LAST_DIGIT_A)
         #define HONEYWELL_MPR_UBAR_SCALING 1563
         #define HONEYWELL_MPR_UBAR_SHIFT 9
         #define GAUGE_PRESSURE
#endif
//gain = 4.768372
 #if defined(HONEYWELL_PRESSURE_RANGE_0025KG) && defined(HONEYWELL_LAST_DIGIT_A)
         #define HONEYWELL_MPR_UBAR_SCALING 2441
         #define HONEYWELL_MPR_UBAR_SHIFT 9
         #define GAUGE_PRESSURE
#endif
//gain = 7.629395
 #if defined(HONEYWELL_PRESSURE_RANGE_0040KG) && defined(HONEYWELL_LAST_DIGIT_A)
         #define HONEYWELL_MPR_UBAR_SCALING 3906
         #define HONEYWELL_MPR_UBAR_SHIFT 9
         #define GAUGE_PRESSURE
#endif
//gain = 11.444092
 #if defined(HONEYWELL_PRESSURE_RANGE_0060KG) && defined(HONEYWELL_LAST_DIGIT_A)
         #define HONEYWELL_MPR_UBAR_SCALING 5859
         #define HONEYWELL_MPR_UBAR_SHIFT 9
         #define GAUGE_PRESSURE
#endif
//gain = 19.073486
 #if defined(HONEYWELL_PRESSURE_RANGE_0100KG) && defined(HONEYWELL_LAST_DIGIT_A)
         #define HONEYWELL_MPR_UBAR_SCALING 9766
         #define HONEYWELL_MPR_UBAR_SHIFT 9
         #define GAUGE_PRESSURE
#endif
//gain = 30.517578
 #if defined(HONEYWELL_PRESSURE_RANGE_0160KG) && defined(HONEYWELL_LAST_DIGIT_A)
         #define HONEYWELL_MPR_UBAR_SCALING 15625
         #define HONEYWELL_MPR_UBAR_SHIFT 9
         #define GAUGE_PRESSURE
#endif
//gain = 47.683716
 #if defined(HONEYWELL_PRESSURE_RANGE_0250KG) && defined(HONEYWELL_LAST_DIGIT_A)
         #define HONEYWELL_MPR_UBAR_SCALING 24414
         #define HONEYWELL_MPR_UBAR_SHIFT 9
         #define GAUGE_PRESSURE
#endif
//gain = 19.726059
 #if defined(HONEYWELL_PRESSURE_RANGE_0015PA) && defined(HONEYWELL_LAST_DIGIT_A)
         #define HONEYWELL_MPR_UBAR_SCALING 10100
         #define HONEYWELL_MPR_UBAR_SHIFT 9
#endif
//gain = 32.876765
 #if defined(HONEYWELL_PRESSURE_RANGE_0025PA) && defined(HONEYWELL_LAST_DIGIT_A)
         #define HONEYWELL_MPR_UBAR_SCALING 16833
         #define HONEYWELL_MPR_UBAR_SHIFT 9
#endif
//gain = 39.452118
 #if defined(HONEYWELL_PRESSURE_RANGE_0030PA) && defined(HONEYWELL_LAST_DIGIT_A)
         #define HONEYWELL_MPR_UBAR_SCALING 20199
         #define HONEYWELL_MPR_UBAR_SHIFT 9
#endif
//gain = 1.315071
 #if defined(HONEYWELL_PRESSURE_RANGE_0001PG) && defined(HONEYWELL_LAST_DIGIT_A)
         #define HONEYWELL_MPR_UBAR_SCALING 673
         #define HONEYWELL_MPR_UBAR_SHIFT 9
         #define GAUGE_PRESSURE
#endif
//gain = 6.575353
 #if defined(HONEYWELL_PRESSURE_RANGE_0005PG) && defined(HONEYWELL_LAST_DIGIT_A)
         #define HONEYWELL_MPR_UBAR_SCALING 3367
         #define HONEYWELL_MPR_UBAR_SHIFT 9
         #define GAUGE_PRESSURE
#endif
//gain = 19.726059
 #if defined(HONEYWELL_PRESSURE_RANGE_0015PG) && defined(HONEYWELL_LAST_DIGIT_A)
         #define HONEYWELL_MPR_UBAR_SCALING 10100
         #define HONEYWELL_MPR_UBAR_SHIFT 9
         #define GAUGE_PRESSURE
#endif
//gain = 39.452118
 #if defined(HONEYWELL_PRESSURE_RANGE_0030PG) && defined(HONEYWELL_LAST_DIGIT_A)
         #define HONEYWELL_MPR_UBAR_SCALING 20199
         #define HONEYWELL_MPR_UBAR_SHIFT 9
         #define GAUGE_PRESSURE
#endif
//gain = 7.628768
 #if defined(HONEYWELL_PRESSURE_RANGE_0300YG) && defined(HONEYWELL_LAST_DIGIT_A)
         #define HONEYWELL_MPR_UBAR_SCALING 3906
         #define HONEYWELL_MPR_UBAR_SHIFT 9
         #define GAUGE_PRESSURE
#endif


#if defined(HONEYWELL_LAST_DIGIT_B)
         #define HONEYWELL_MPR_UBAR_OFFSET 419430
#endif
//gain = 76.293945
 #if defined(HONEYWELL_PRESSURE_RANGE_0001BA) && defined(HONEYWELL_LAST_DIGIT_B)
         #define HONEYWELL_MPR_UBAR_SCALING 39063
         #define HONEYWELL_MPR_UBAR_SHIFT 9
#endif
//gain = 122.070312
 #if defined(HONEYWELL_PRESSURE_RANGE_01_6BA) && defined(HONEYWELL_LAST_DIGIT_B)
         #define HONEYWELL_MPR_UBAR_SCALING 62500
         #define HONEYWELL_MPR_UBAR_SHIFT 9
#endif
//gain = 190.734863
 #if defined(HONEYWELL_PRESSURE_RANGE_02_5BA) && defined(HONEYWELL_LAST_DIGIT_B)
         #define HONEYWELL_MPR_UBAR_SCALING 97656
         #define HONEYWELL_MPR_UBAR_SHIFT 9
#endif
//gain = 4.577637
 #if defined(HONEYWELL_PRESSURE_RANGE_0060MG) && defined(HONEYWELL_LAST_DIGIT_B)
         #define HONEYWELL_MPR_UBAR_SCALING 2344
         #define HONEYWELL_MPR_UBAR_SHIFT 9
         #define GAUGE_PRESSURE
#endif
//gain = 7.629395
 #if defined(HONEYWELL_PRESSURE_RANGE_0100MG) && defined(HONEYWELL_LAST_DIGIT_B)
         #define HONEYWELL_MPR_UBAR_SCALING 3906
         #define HONEYWELL_MPR_UBAR_SHIFT 9
         #define GAUGE_PRESSURE
#endif
//gain = 12.207031
 #if defined(HONEYWELL_PRESSURE_RANGE_0160MG) && defined(HONEYWELL_LAST_DIGIT_B)
         #define HONEYWELL_MPR_UBAR_SCALING 6250
         #define HONEYWELL_MPR_UBAR_SHIFT 9
         #define GAUGE_PRESSURE
#endif
//gain = 19.073486
 #if defined(HONEYWELL_PRESSURE_RANGE_0250MG) && defined(HONEYWELL_LAST_DIGIT_B)
         #define HONEYWELL_MPR_UBAR_SCALING 9766
         #define HONEYWELL_MPR_UBAR_SHIFT 9
         #define GAUGE_PRESSURE
#endif
//gain = 30.517578
 #if defined(HONEYWELL_PRESSURE_RANGE_0400MG) && defined(HONEYWELL_LAST_DIGIT_B)
         #define HONEYWELL_MPR_UBAR_SCALING 15625
         #define HONEYWELL_MPR_UBAR_SHIFT 9
         #define GAUGE_PRESSURE
#endif
//gain = 45.776367
 #if defined(HONEYWELL_PRESSURE_RANGE_0600MG) && defined(HONEYWELL_LAST_DIGIT_B)
         #define HONEYWELL_MPR_UBAR_SCALING 23438
         #define HONEYWELL_MPR_UBAR_SHIFT 9
         #define GAUGE_PRESSURE
#endif
//gain = 76.293945
 #if defined(HONEYWELL_PRESSURE_RANGE_0001BG) && defined(HONEYWELL_LAST_DIGIT_B)
         #define HONEYWELL_MPR_UBAR_SCALING 39063
         #define HONEYWELL_MPR_UBAR_SHIFT 9
         #define GAUGE_PRESSURE
#endif
//gain = 122.070312
 #if defined(HONEYWELL_PRESSURE_RANGE_01_6BG) && defined(HONEYWELL_LAST_DIGIT_B)
         #define HONEYWELL_MPR_UBAR_SCALING 62500
         #define HONEYWELL_MPR_UBAR_SHIFT 9
         #define GAUGE_PRESSURE
#endif
//gain = 190.734863
 #if defined(HONEYWELL_PRESSURE_RANGE_02_5BG) && defined(HONEYWELL_LAST_DIGIT_B)
         #define HONEYWELL_MPR_UBAR_SCALING 97656
         #define HONEYWELL_MPR_UBAR_SHIFT 9
         #define GAUGE_PRESSURE
#endif
//gain = 76.293945
 #if defined(HONEYWELL_PRESSURE_RANGE_0100KA) && defined(HONEYWELL_LAST_DIGIT_B)
         #define HONEYWELL_MPR_UBAR_SCALING 39063
         #define HONEYWELL_MPR_UBAR_SHIFT 9
#endif
//gain = 122.070312
 #if defined(HONEYWELL_PRESSURE_RANGE_0160KA) && defined(HONEYWELL_LAST_DIGIT_B)
         #define HONEYWELL_MPR_UBAR_SCALING 62500
         #define HONEYWELL_MPR_UBAR_SHIFT 9
#endif
//gain = 190.734863
 #if defined(HONEYWELL_PRESSURE_RANGE_0250KA) && defined(HONEYWELL_LAST_DIGIT_B)
         #define HONEYWELL_MPR_UBAR_SCALING 97656
         #define HONEYWELL_MPR_UBAR_SHIFT 9
#endif
//gain = 4.577637
 #if defined(HONEYWELL_PRESSURE_RANGE_0006KG) && defined(HONEYWELL_LAST_DIGIT_B)
         #define HONEYWELL_MPR_UBAR_SCALING 2344
         #define HONEYWELL_MPR_UBAR_SHIFT 9
         #define GAUGE_PRESSURE
#endif
//gain = 7.629395
 #if defined(HONEYWELL_PRESSURE_RANGE_0010KG) && defined(HONEYWELL_LAST_DIGIT_B)
         #define HONEYWELL_MPR_UBAR_SCALING 3906
         #define HONEYWELL_MPR_UBAR_SHIFT 9
         #define GAUGE_PRESSURE
#endif
//gain = 12.207031
 #if defined(HONEYWELL_PRESSURE_RANGE_0016KG) && defined(HONEYWELL_LAST_DIGIT_B)
         #define HONEYWELL_MPR_UBAR_SCALING 6250
         #define HONEYWELL_MPR_UBAR_SHIFT 9
         #define GAUGE_PRESSURE
#endif
//gain = 19.073486
 #if defined(HONEYWELL_PRESSURE_RANGE_0025KG) && defined(HONEYWELL_LAST_DIGIT_B)
         #define HONEYWELL_MPR_UBAR_SCALING 9766
         #define HONEYWELL_MPR_UBAR_SHIFT 9
         #define GAUGE_PRESSURE
#endif
//gain = 30.517578
 #if defined(HONEYWELL_PRESSURE_RANGE_0040KG) && defined(HONEYWELL_LAST_DIGIT_B)
         #define HONEYWELL_MPR_UBAR_SCALING 15625
         #define HONEYWELL_MPR_UBAR_SHIFT 9
         #define GAUGE_PRESSURE
#endif
//gain = 45.776367
 #if defined(HONEYWELL_PRESSURE_RANGE_0060KG) && defined(HONEYWELL_LAST_DIGIT_B)
         #define HONEYWELL_MPR_UBAR_SCALING 23438
         #define HONEYWELL_MPR_UBAR_SHIFT 9
         #define GAUGE_PRESSURE
#endif
//gain = 76.293945
 #if defined(HONEYWELL_PRESSURE_RANGE_0100KG) && defined(HONEYWELL_LAST_DIGIT_B)
         #define HONEYWELL_MPR_UBAR_SCALING 39063
         #define HONEYWELL_MPR_UBAR_SHIFT 9
         #define GAUGE_PRESSURE
#endif
//gain = 122.070312
 #if defined(HONEYWELL_PRESSURE_RANGE_0160KG) && defined(HONEYWELL_LAST_DIGIT_B)
         #define HONEYWELL_MPR_UBAR_SCALING 62500
         #define HONEYWELL_MPR_UBAR_SHIFT 9
         #define GAUGE_PRESSURE
#endif
//gain = 190.734863
 #if defined(HONEYWELL_PRESSURE_RANGE_0250KG) && defined(HONEYWELL_LAST_DIGIT_B)
         #define HONEYWELL_MPR_UBAR_SCALING 97656
         #define HONEYWELL_MPR_UBAR_SHIFT 9
         #define GAUGE_PRESSURE
#endif
//gain = 78.904235
 #if defined(HONEYWELL_PRESSURE_RANGE_0015PA) && defined(HONEYWELL_LAST_DIGIT_B)
         #define HONEYWELL_MPR_UBAR_SCALING 40399
         #define HONEYWELL_MPR_UBAR_SHIFT 9
#endif
//gain = 131.507059
 #if defined(HONEYWELL_PRESSURE_RANGE_0025PA) && defined(HONEYWELL_LAST_DIGIT_B)
         #define HONEYWELL_MPR_UBAR_SCALING 67332
         #define HONEYWELL_MPR_UBAR_SHIFT 9
#endif
//gain = 157.808471
 #if defined(HONEYWELL_PRESSURE_RANGE_0030PA) && defined(HONEYWELL_LAST_DIGIT_B)
         #define HONEYWELL_MPR_UBAR_SCALING 80798
         #define HONEYWELL_MPR_UBAR_SHIFT 9
#endif
//gain = 5.260282
 #if defined(HONEYWELL_PRESSURE_RANGE_0001PG) && defined(HONEYWELL_LAST_DIGIT_B)
         #define HONEYWELL_MPR_UBAR_SCALING 2693
         #define HONEYWELL_MPR_UBAR_SHIFT 9
         #define GAUGE_PRESSURE
#endif
//gain = 26.301412
 #if defined(HONEYWELL_PRESSURE_RANGE_0005PG) && defined(HONEYWELL_LAST_DIGIT_B)
         #define HONEYWELL_MPR_UBAR_SCALING 13466
         #define HONEYWELL_MPR_UBAR_SHIFT 9
         #define GAUGE_PRESSURE
#endif
//gain = 78.904235
 #if defined(HONEYWELL_PRESSURE_RANGE_0015PG) && defined(HONEYWELL_LAST_DIGIT_B)
         #define HONEYWELL_MPR_UBAR_SCALING 40399
         #define HONEYWELL_MPR_UBAR_SHIFT 9
         #define GAUGE_PRESSURE
#endif
//gain = 157.808471
 #if defined(HONEYWELL_PRESSURE_RANGE_0030PG) && defined(HONEYWELL_LAST_DIGIT_B)
         #define HONEYWELL_MPR_UBAR_SCALING 80798
         #define HONEYWELL_MPR_UBAR_SHIFT 9
         #define GAUGE_PRESSURE
#endif
//gain = 30.515073
 #if defined(HONEYWELL_PRESSURE_RANGE_0300YG) && defined(HONEYWELL_LAST_DIGIT_B)
         #define HONEYWELL_MPR_UBAR_SCALING 15624
         #define HONEYWELL_MPR_UBAR_SHIFT 9
         #define GAUGE_PRESSURE
#endif


#if defined(HONEYWELL_LAST_DIGIT_C)
         #define HONEYWELL_MPR_UBAR_OFFSET 3355443
#endif
//gain = 25.431315
 #if defined(HONEYWELL_PRESSURE_RANGE_0001BA) && defined(HONEYWELL_LAST_DIGIT_C)
         #define HONEYWELL_MPR_UBAR_SCALING 13021
         #define HONEYWELL_MPR_UBAR_SHIFT 9
#endif
//gain = 40.690104
 #if defined(HONEYWELL_PRESSURE_RANGE_01_6BA) && defined(HONEYWELL_LAST_DIGIT_C)
         #define HONEYWELL_MPR_UBAR_SCALING 20833
         #define HONEYWELL_MPR_UBAR_SHIFT 9
#endif
//gain = 63.578288
 #if defined(HONEYWELL_PRESSURE_RANGE_02_5BA) && defined(HONEYWELL_LAST_DIGIT_C)
         #define HONEYWELL_MPR_UBAR_SCALING 32552
         #define HONEYWELL_MPR_UBAR_SHIFT 9
#endif
//gain = 1.525879
 #if defined(HONEYWELL_PRESSURE_RANGE_0060MG) && defined(HONEYWELL_LAST_DIGIT_C)
         #define HONEYWELL_MPR_UBAR_SCALING 781
         #define HONEYWELL_MPR_UBAR_SHIFT 9
         #define GAUGE_PRESSURE
#endif
//gain = 2.543132
 #if defined(HONEYWELL_PRESSURE_RANGE_0100MG) && defined(HONEYWELL_LAST_DIGIT_C)
         #define HONEYWELL_MPR_UBAR_SCALING 1302
         #define HONEYWELL_MPR_UBAR_SHIFT 9
         #define GAUGE_PRESSURE
#endif
//gain = 4.069010
 #if defined(HONEYWELL_PRESSURE_RANGE_0160MG) && defined(HONEYWELL_LAST_DIGIT_C)
         #define HONEYWELL_MPR_UBAR_SCALING 2083
         #define HONEYWELL_MPR_UBAR_SHIFT 9
         #define GAUGE_PRESSURE
#endif
//gain = 6.357829
 #if defined(HONEYWELL_PRESSURE_RANGE_0250MG) && defined(HONEYWELL_LAST_DIGIT_C)
         #define HONEYWELL_MPR_UBAR_SCALING 3255
         #define HONEYWELL_MPR_UBAR_SHIFT 9
         #define GAUGE_PRESSURE
#endif
//gain = 10.172526
 #if defined(HONEYWELL_PRESSURE_RANGE_0400MG) && defined(HONEYWELL_LAST_DIGIT_C)
         #define HONEYWELL_MPR_UBAR_SCALING 5208
         #define HONEYWELL_MPR_UBAR_SHIFT 9
         #define GAUGE_PRESSURE
#endif
//gain = 15.258789
 #if defined(HONEYWELL_PRESSURE_RANGE_0600MG) && defined(HONEYWELL_LAST_DIGIT_C)
         #define HONEYWELL_MPR_UBAR_SCALING 7812
         #define HONEYWELL_MPR_UBAR_SHIFT 9
         #define GAUGE_PRESSURE
#endif
//gain = 25.431315
 #if defined(HONEYWELL_PRESSURE_RANGE_0001BG) && defined(HONEYWELL_LAST_DIGIT_C)
         #define HONEYWELL_MPR_UBAR_SCALING 13021
         #define HONEYWELL_MPR_UBAR_SHIFT 9
         #define GAUGE_PRESSURE
#endif
//gain = 40.690104
 #if defined(HONEYWELL_PRESSURE_RANGE_01_6BG) && defined(HONEYWELL_LAST_DIGIT_C)
         #define HONEYWELL_MPR_UBAR_SCALING 20833
         #define HONEYWELL_MPR_UBAR_SHIFT 9
         #define GAUGE_PRESSURE
#endif
//gain = 63.578288
 #if defined(HONEYWELL_PRESSURE_RANGE_02_5BG) && defined(HONEYWELL_LAST_DIGIT_C)
         #define HONEYWELL_MPR_UBAR_SCALING 32552
         #define HONEYWELL_MPR_UBAR_SHIFT 9
         #define GAUGE_PRESSURE
#endif
//gain = 25.431315
 #if defined(HONEYWELL_PRESSURE_RANGE_0100KA) && defined(HONEYWELL_LAST_DIGIT_C)
         #define HONEYWELL_MPR_UBAR_SCALING 13021
         #define HONEYWELL_MPR_UBAR_SHIFT 9
#endif
//gain = 40.690104
 #if defined(HONEYWELL_PRESSURE_RANGE_0160KA) && defined(HONEYWELL_LAST_DIGIT_C)
         #define HONEYWELL_MPR_UBAR_SCALING 20833
         #define HONEYWELL_MPR_UBAR_SHIFT 9
#endif
//gain = 63.578288
 #if defined(HONEYWELL_PRESSURE_RANGE_0250KA) && defined(HONEYWELL_LAST_DIGIT_C)
         #define HONEYWELL_MPR_UBAR_SCALING 32552
         #define HONEYWELL_MPR_UBAR_SHIFT 9
#endif
//gain = 1.525879
 #if defined(HONEYWELL_PRESSURE_RANGE_0006KG) && defined(HONEYWELL_LAST_DIGIT_C)
         #define HONEYWELL_MPR_UBAR_SCALING 781
         #define HONEYWELL_MPR_UBAR_SHIFT 9
         #define GAUGE_PRESSURE
#endif
//gain = 2.543132
 #if defined(HONEYWELL_PRESSURE_RANGE_0010KG) && defined(HONEYWELL_LAST_DIGIT_C)
         #define HONEYWELL_MPR_UBAR_SCALING 1302
         #define HONEYWELL_MPR_UBAR_SHIFT 9
         #define GAUGE_PRESSURE
#endif
//gain = 4.069010
 #if defined(HONEYWELL_PRESSURE_RANGE_0016KG) && defined(HONEYWELL_LAST_DIGIT_C)
         #define HONEYWELL_MPR_UBAR_SCALING 2083
         #define HONEYWELL_MPR_UBAR_SHIFT 9
         #define GAUGE_PRESSURE
#endif
//gain = 6.357829
 #if defined(HONEYWELL_PRESSURE_RANGE_0025KG) && defined(HONEYWELL_LAST_DIGIT_C)
         #define HONEYWELL_MPR_UBAR_SCALING 3255
         #define HONEYWELL_MPR_UBAR_SHIFT 9
         #define GAUGE_PRESSURE
#endif
//gain = 10.172526
 #if defined(HONEYWELL_PRESSURE_RANGE_0040KG) && defined(HONEYWELL_LAST_DIGIT_C)
         #define HONEYWELL_MPR_UBAR_SCALING 5208
         #define HONEYWELL_MPR_UBAR_SHIFT 9
         #define GAUGE_PRESSURE
#endif
//gain = 15.258789
 #if defined(HONEYWELL_PRESSURE_RANGE_0060KG) && defined(HONEYWELL_LAST_DIGIT_C)
         #define HONEYWELL_MPR_UBAR_SCALING 7812
         #define HONEYWELL_MPR_UBAR_SHIFT 9
         #define GAUGE_PRESSURE
#endif
//gain = 25.431315
 #if defined(HONEYWELL_PRESSURE_RANGE_0100KG) && defined(HONEYWELL_LAST_DIGIT_C)
         #define HONEYWELL_MPR_UBAR_SCALING 13021
         #define HONEYWELL_MPR_UBAR_SHIFT 9
         #define GAUGE_PRESSURE
#endif
//gain = 40.690104
 #if defined(HONEYWELL_PRESSURE_RANGE_0160KG) && defined(HONEYWELL_LAST_DIGIT_C)
         #define HONEYWELL_MPR_UBAR_SCALING 20833
         #define HONEYWELL_MPR_UBAR_SHIFT 9
         #define GAUGE_PRESSURE
#endif
//gain = 63.578288
 #if defined(HONEYWELL_PRESSURE_RANGE_0250KG) && defined(HONEYWELL_LAST_DIGIT_C)
         #define HONEYWELL_MPR_UBAR_SCALING 32552
         #define HONEYWELL_MPR_UBAR_SHIFT 9
         #define GAUGE_PRESSURE
#endif
//gain = 26.301412
 #if defined(HONEYWELL_PRESSURE_RANGE_0015PA) && defined(HONEYWELL_LAST_DIGIT_C)
         #define HONEYWELL_MPR_UBAR_SCALING 13466
         #define HONEYWELL_MPR_UBAR_SHIFT 9
#endif
//gain = 43.835686
 #if defined(HONEYWELL_PRESSURE_RANGE_0025PA) && defined(HONEYWELL_LAST_DIGIT_C)
         #define HONEYWELL_MPR_UBAR_SCALING 22444
         #define HONEYWELL_MPR_UBAR_SHIFT 9
#endif
//gain = 52.602824
 #if defined(HONEYWELL_PRESSURE_RANGE_0030PA) && defined(HONEYWELL_LAST_DIGIT_C)
         #define HONEYWELL_MPR_UBAR_SCALING 26933
         #define HONEYWELL_MPR_UBAR_SHIFT 9
#endif
//gain = 1.753427
 #if defined(HONEYWELL_PRESSURE_RANGE_0001PG) && defined(HONEYWELL_LAST_DIGIT_C)
         #define HONEYWELL_MPR_UBAR_SCALING 898
         #define HONEYWELL_MPR_UBAR_SHIFT 9
         #define GAUGE_PRESSURE
#endif
//gain = 8.767137
 #if defined(HONEYWELL_PRESSURE_RANGE_0005PG) && defined(HONEYWELL_LAST_DIGIT_C)
         #define HONEYWELL_MPR_UBAR_SCALING 4489
         #define HONEYWELL_MPR_UBAR_SHIFT 9
         #define GAUGE_PRESSURE
#endif
//gain = 26.301412
 #if defined(HONEYWELL_PRESSURE_RANGE_0015PG) && defined(HONEYWELL_LAST_DIGIT_C)
         #define HONEYWELL_MPR_UBAR_SCALING 13466
         #define HONEYWELL_MPR_UBAR_SHIFT 9
         #define GAUGE_PRESSURE
#endif
//gain = 52.602824
 #if defined(HONEYWELL_PRESSURE_RANGE_0030PG) && defined(HONEYWELL_LAST_DIGIT_C)
         #define HONEYWELL_MPR_UBAR_SCALING 26933
         #define HONEYWELL_MPR_UBAR_SHIFT 9
         #define GAUGE_PRESSURE
#endif
//gain = 10.171691
 #if defined(HONEYWELL_PRESSURE_RANGE_0300YG) && defined(HONEYWELL_LAST_DIGIT_C)
         #define HONEYWELL_MPR_UBAR_SCALING 5208
         #define HONEYWELL_MPR_UBAR_SHIFT 9
         #define GAUGE_PRESSURE
#endif


#endif // I2CHONEYWELLMPR_H
