/*
 * Copyright (C) LEE Ventus - All Rights Reserved
 * Unauthorised copying of this file, via any medium is strictly prohibited
 * Proprietary and confidential
 */

#include "i2cLP5861GaugeHandler.h"

#include "LEDValueGenerator.h"



static uint16_t gaugeLevel;
static uint8_t r;
static uint8_t g;
static uint8_t b;

rgb_led_state RGB_LED_state = RGB_LED_READY;
static uint16_t counter = 0;


void LP5861_setGaugemW(uint16_t milliwatts)
{
    gaugeLevel = milliwatts;
}

// TODO integrate the SPM into an LED controller wrapper so we can actually test it. Atm we can only test the GP driver
void LP5861_setLEDColour(uint16_t RGB_value)
{
	//discard the 1st bit as we are using 5-5-5 bits for RGB
	//the green led is much brighter than the others so adjusting for it
	b = ( RGB_value			& 0b11111)<<2;	//B
	r = ((RGB_value>> 10) 	& 0b11111)<<2;	//R
	g = ((RGB_value>> 5) 	& 0b11111)<<1;	//G
}

void LP5861_led_setState(rgb_led_state state)
{
	RGB_LED_state = state;
}

void LP5861_tick()
{
	if(++counter > 2048)
		counter = 0;
}






typedef enum driverState
{
    ENABLE,
	SETUP,
	IDLE
} driverState;

static i2c_request service();
static uint16_t writeCompleteCallback(bool success);

static driverState state;
static uint8_t buf[4];


i2c_device LP5861_getDevice()
{
	state = ENABLE;
	counter = 0;

	i2c_device device;

	device.i2cAddr = LP5861_I2C_BASE_ADDRESS;
	device.serviceI2CDevice = service;

	return device;
}

static i2c_request service()
{
	i2c_request request;

	    switch(state)
	    {
	        case ENABLE:
	            buf[0] = 0x00;
	            buf[1] = 0x01;
				request.type = I2C_WRITE;
				request.count = 2;
				break;

	        case SETUP:
	        	buf[0] = 0x01;
				buf[1] = 0x5E & (~0b110);	//mode 1
				buf[2] = 0x2;				//pwm phase shift
				buf[3] = 0x2<<6;
				request.type = I2C_WRITE;
				request.count = 4;
				break;

	        case IDLE:
				request.type = I2C_READ;
				request.count = 1;
				break;
	    }

	    request.buf = buf;
	    request.requestCompleteCallback = writeCompleteCallback;

	    return request;
}

static uint16_t writeCompleteCallback(bool success)
{
    switch(state)
    {
        case ENABLE:
        	if(success)
			{
        		state = SETUP;
        		return 5; // some time to boot up
			}
        	return 25;

        case SETUP:
        	if(success)
			{
				state = IDLE;
				return 0xFFFF;		//set this to as long as possible
			}
			return 25;

        case IDLE:
			return 0xFFFF;		//set this to as long as possible

    }
    return 0;
}





typedef enum driverStateBrigthness
{
	SET_BRIGHTNESS
} driverStateBrigthness;

static i2c_request serviceBrightness();
static uint16_t writeCompleteCallbackBrightness(bool success);

static driverStateBrigthness stateBrightness;
static uint8_t bufBrightness[20];


//brightness control is seperate as it is a different i2c address than the base device...
i2c_device LP5861BrigthnessControl_getDevice()
{
	stateBrightness = SET_BRIGHTNESS;

	i2c_device device;

	device.i2cAddr = LP5861_I2C_BRIGHTNESS_ADDRESS;//base 100 addr pins 10 registers 01
	device.serviceI2CDevice = serviceBrightness;

	return device;
}

static i2c_request serviceBrightness()
{
	i2c_request request;

	    switch(stateBrightness)
	    {
	    	// this code is nearly identical with the one in SPM project -> SinglePumpModuleCode -> led.c
	    	// so make sure the two are consistent
	        case SET_BRIGHTNESS:
	        	request.type = I2C_WRITE;
				request.count = 18;

	            bufBrightness[0]  = 0x00;	//address
				generateGaugeLedValues(gaugeLevel, &(bufBrightness[1]));

				switch(RGB_LED_state)
				{
					case RGB_LED_READY:
						// we want the brightness of the breathing state to be lower
						// than the one of the running state so the two are easily distinguished
						// so brightness * 3/4 here
						if(counter < 1024)
						{
							bufBrightness[15] = (b * counter * 3) / 4096;	//B
							bufBrightness[16] = (r * counter * 3) / 4096;	//R
							bufBrightness[17] = (g * counter * 3) / 4096;	//G
						}
						else
						{
							bufBrightness[15] = (b * (2048-counter) * 3) / 4096;	//B
							bufBrightness[16] = (r * (2048-counter) * 3) / 4096;	//R
							bufBrightness[17] = (g * (2048-counter) * 3) / 4096;	//G
						}
						break;

					case RGB_LED_RUNNING:
						counter = 1536;	// when we turn off this will set the LED to half brightness and decreasing
						bufBrightness[15] = b;	//B
						bufBrightness[16] = r;	//R
						bufBrightness[17] = g;	//G
						break;

					case RGB_LED_ERROR:
						// in error state we want to blink red
						// but also be able to identify which board it is (by the colour set)
						// so also quickly flash the RGB colour set

						if(counter % 1024 < 512){
							bufBrightness[16] = 255;	//R
							bufBrightness[15] = 0;		//B
							bufBrightness[17] = 0;		//G
						}else if(counter % 1024 > 768){
							bufBrightness[15] = b;	//B
							bufBrightness[16] = r;	//R
							bufBrightness[17] = g;	//G
						}else{
							bufBrightness[16] = 0;		//R
							bufBrightness[15] = 0;		//B
							bufBrightness[17] = 0;		//G
						}
						break;
				}


				break;

	    }

	    request.buf = bufBrightness;
	    request.requestCompleteCallback = writeCompleteCallbackBrightness;

	    return request;
}

static uint16_t writeCompleteCallbackBrightness(bool success)
{
    switch(stateBrightness)
    {
        case SET_BRIGHTNESS:
            return 16;	//60hz
    }
    return 0;
}



