/*
 * Copyright (C) LEE Ventus - All Rights Reserved
 * Unauthorised copying of this file, via any medium is strictly prohibited
 * Proprietary and confidential
 */
#ifndef I2CSLAVEHANDLER_H
#define I2CSLAVEHANDLER_H

#include <stdbool.h>
#include <stdint.h>

// Master starts write
//  -Master starts write with our slave address
//  -HAL sends callback, with read/write bit set to 0 (master writes)
//  -We request 1 byte from I2C
//  -HAL sends callback once byte is received
//  -MSBit indicates read/write, where read is 1, write is 0
//  -7 LSBits are the setting to read/write
//
//  -IF WRITE COMMAND
//      -Check setting type
//      -Request appropriate number of bytes from I2C
//      -HAL sends callback with bytes
//      -Write bytes to the setting
//
//  -IF READ COMMAND
//      -Get ready to send back this value on the next master read
//

// Master starts read
//  -Master starts read with our slave address
//  -HAL sends callback, with read/write bit set to 1 (master reads)
//  -We request to send correct number of bytes for whatever 
//   setting was previously requested
//  -If no setting was requested, return stream values

typedef struct i2cSlaveHandler_settings
{
    void (*writeBytesToMaster)(uint8_t* bytesToWrite,
                               uint8_t bytesToWriteLen);

    void (*receiveBytesFromMaster)(uint8_t* receivedBytes,
                                   uint8_t numberOfBytesToReceive);

    uint8_t* settingsToStream;  // A list of settings to send in streaming mode
	uint8_t settingsToStreamCount;  // Length of the settings to be streamed
} i2cSlaveHandler_settings;

void i2cSlaveHandler_init(i2cSlaveHandler_settings settings);

// Called when the I2C detects that the master has initiated a message
void i2cSlaveHandler_masterStartedMessage(bool isWrite);

// Called when I2C has finished receiving bytes from the master
void i2cSlaveHandler_slaveFinishedReceiving();

// Call to turn streaming off or on
void i2cSlaveHandler_setStreaming(bool enabled);


#endif // I2CSLAVEHANDLER_H
