/*
 * Copyright (C) LEE Ventus - All Rights Reserved
 * Unauthorised copying of this file, via any medium is strictly prohibited
 * Proprietary and confidential
 */
#define SETUP_REG_COUNT (6)

#include "i2cTlc59116GaugeHandler.h"

#include "LEDValueGenerator.h"

typedef enum driverState
{
    SETUP,
    RUNNING
} driverState;

static i2c_request service();
static uint16_t writeCompleteCallback(bool success);

static driverState state;
static uint16_t gaugeLevel;
static uint8_t buf[17];

static uint8_t regWriting = 0;
static const uint8_t setupRegIndexs[SETUP_REG_COUNT] = {0, 1, 20, 21, 22, 23};
static const uint8_t setupRegValues[SETUP_REG_COUNT] = {1, 0, 170, 170, 170, 170};

i2c_device tlc59116_getDevice()
{
    regWriting = 0;
    gaugeLevel = 0;
    state = SETUP;

    i2c_device device;

    device.i2cAddr = TI_TLC59116_I2C_ADDR;
    device.serviceI2CDevice = service;

    return device;
}

void tlc59116_setGaugemW(uint16_t milliwatts)
{
    gaugeLevel = milliwatts;
}

void tlc59116_setErrorLed(bool showError)
{
    buf[15] = showError * 255;
}

void tlc59116_setDriverOnLed(bool showDriverOn)
{
    buf[16] = showDriverOn * 255;
}

static i2c_request service()
{
    i2c_request request;

    switch(state)
    {
        case SETUP:
            buf[0] = setupRegIndexs[regWriting];
            buf[1] = setupRegValues[regWriting];

            request.type = I2C_WRITE;
            request.count = 2;
            request.buf = buf;
            request.requestCompleteCallback = writeCompleteCallback;

            return request;

        case RUNNING:
            request.type = I2C_WRITE;
            request.count = 17;
            request.buf = buf;
            request.requestCompleteCallback = writeCompleteCallback;

            buf[0] = 162;
            generateGaugeLedValues(gaugeLevel, &(buf[1]));

            return request;

        default:
        	return request;
    }
}

static uint16_t writeCompleteCallback(bool success)
{
    switch(state)
    {
        case SETUP:
            if(success) 
            {
                regWriting++;

                if(regWriting == SETUP_REG_COUNT)
                    state = RUNNING;

                return 0;
            }

            return 25;

        case RUNNING:
            // Just ignore failure, update every 16ms
            return 16;

        default:
        	return 0;
    }
}


