/*
 * Copyright (C) LEE Ventus - All Rights Reserved
 * Unauthorised copying of this file, via any medium is strictly prohibited
 * Proprietary and confidential
 */
#include "fastATan2.h"

static float magnitude(float val);

float fastATan2(float x, float y)
{
    // Handle case where both are zero
    if(x==0 && y==0)
        return 0;

    uint8_t yLargest = magnitude(y) > magnitude(x);
    uint8_t yNegative = y < 0;
    uint8_t xNegative = x < 0;

    float z = yLargest ? x/y : y/x;  // Limit z to -1 to 1
    z = z>=0 ? z : -1*z;  // Limit z to 0 to 1

    float phase = z * (45 - 15.66*(z-1));

    if(!yLargest)
        phase = 90 - phase;

    if(yNegative)
        phase = 180 - phase;

    if(xNegative)
        phase *= -1;

    return phase;
}

static float magnitude(float val)
{
    if(val >= 0)
        return val;

    return -1 * val;
}
