/*
 * Copyright (C) LEE Ventus - All Rights Reserved
 * Unauthorised copying of this file, via any medium is strictly prohibited
 * Proprietary and confidential
 */

/*
 * Phase detector module used to detect the phase between 2x signals, where the
 * frequency is already known.
 *
 * Start the module with phaseDetector_init, setting the frequency both signals 
 * are sampled at, and the smoothingFactor, which applies an exponential filter
 * to the calculated phase. The filter factor is 2^smoothingFactor 
 * In most cases smoothingFactor will need to be at least 4. 
 * Also pass the initial frequency the signals are expected to be at.
 *
 * When new samples are collected, pass these to 
 * phaseDetector_setSignalFrequency
 *
 * If the known frequency changes, you can set this as any time using 
 * phaseDetector_setSignalFrequency
 *
 * Then you can call phaseDetector_new
 */
#ifndef PHASEDETECTOR_H
#define PHASEDETECTOR_H

#include <stdint.h>

typedef struct phaseDetector_update
{
    int32_t amplitudeARms;
    int32_t amplitudeBRms;
    float phaseDegrees;
} phaseDetector_update;

// Initialise the module
void phaseDetector_init(uint32_t samplingFrequency,
                        uint8_t smoothingFactor, 
                        uint32_t initialFrequencyHz);

// Call to set the expected frequency of the signals
void phaseDetector_setSignalFrequency(uint32_t frequencyHz);

// Push new samples to the phase detector
void phaseDetector_newSamples(int16_t signalASample, int16_t signalBSample);

// Get a struct, containing the latest phase / magnitude values
phaseDetector_update phaseDetector_getUpdate();


#endif // PHASEDETECTOR_H
