/*
 * Copyright (C) LEE Ventus - All Rights Reserved
 * Unauthorised copying of this file, via any medium is strictly prohibited
 * Proprietary and confidential
 */
#include "Sampling.h"
#include <stdlib.h>

typedef struct sampling_channel
{
    uint8_t filterFactor;
    int32_t scale;
    uint8_t rightShift;
    volatile int32_t accumulator;
    volatile int32_t rawValue;
} sampling_channel;

static sampling_channel* channels;

void sampling_setup(uint8_t channelCount, 
                    sampling_channelConfig* channelConfigs)
{
    channels = malloc(sizeof(sampling_channel) * channelCount);

    for(uint8_t chanIdx=0; chanIdx<channelCount; chanIdx++)
    {
        sampling_channelConfig config = channelConfigs[chanIdx];
        channels[chanIdx].filterFactor = config.oversamplingFactor;
        channels[chanIdx].scale = (int32_t)config.scalingMulti;
        channels[chanIdx].rightShift = config.scalingRightShift;
        channels[chanIdx].accumulator = 0;
        channels[chanIdx].rawValue = 0;
    }
}

void sampling_updateChannel(uint8_t channelId, int32_t newValue)
{
    // Update raw value
    channels[channelId].rawValue = newValue;

    // Update the accumulator
    channels[channelId].accumulator -= channels[channelId].accumulator >>
                                       channels[channelId].filterFactor;
    channels[channelId].accumulator += newValue;
}

int32_t sampling_getChannelFiltered(uint8_t channelId)
{
    int32_t filteredValue = channels[channelId].accumulator >> 
                            channels[channelId].filterFactor;

    int32_t scaled = filteredValue * channels[channelId].scale;

    return scaled >> channels[channelId].rightShift;
}

int32_t sampling_getChannelRaw(uint8_t channelId)
{
    int32_t scaled = channels[channelId].rawValue * channels[channelId].scale;

    return scaled >> channels[channelId].rightShift;
}
