/*
 * Copyright (C) LEE Ventus - All Rights Reserved
 * Unauthorised copying of this file, via any medium is strictly prohibited
 * Proprietary and confidential
 */
#include "Settings.h"
#include "stringHandler.h"

// Build server sets this flag to allow version numbers to be inserted
#define IS_BUILD_SERVER_BUILD 1

#if IS_BUILD_SERVER_BUILD
    #define MAJOR_FW_VERSION (15)
    #define MINOR_FW_VERSION (11)
#else
    #define MAJOR_FW_VERSION (0)
    #define MINOR_FW_VERSION (0)
#endif

#ifdef SINGLE_PUMP_MODULE
    #define DRIVER_TYPE 3
    #define DEFAULT_ANA_B_OFFSET (-610)
#elif SOFT_DRIVER
    #define DRIVER_TYPE 4 
    #define DEFAULT_ANA_B_OFFSET (-810)
#else
    #define DRIVER_TYPE 2  // Cost Optimised driver
    #define DEFAULT_ANA_B_OFFSET (-821)
#endif

#ifdef SINGLE_PUMP_MODULE
    #define DEFAULT_MANUAL_MODE_SOURCE (SETTINGS_SOURCE_ANA3)
    #define DEFAULT_PID_SETPOINT (SETTINGS_SOURCE_ANA3)
    #define DEFAULT_PID_MEAS (SETTINGS_SOURCE_PRESSURE)
	#define DEFAULT_BANGBANG_MEAS (SETTINGS_SOURCE_PRESSURE)
	#define MAX_STREAMING_MODE (2)
#else
    #define DEFAULT_MANUAL_MODE_SOURCE (SETTINGS_SOURCE_ANA1)
    #define DEFAULT_PID_SETPOINT (SETTINGS_SOURCE_ANA1)
    #define DEFAULT_PID_MEAS (SETTINGS_SOURCE_PRESSURE)
	#define DEFAULT_BANGBANG_MEAS (SETTINGS_SOURCE_PRESSURE)
	#define MAX_STREAMING_MODE (1)
#endif

// the default state of GPIO pins is different for each board
// so is the minimum state (as some pins do not support high speed output
#ifdef COST_OPTIMISED_DRIVER
	#define GPIOA_DEFAULT_STATE INPUT_PULL_UP
	#define GPIOA_MINIMUM_STATE OUTPUT_LOW_SPEED_DEF_ON

	#define GPIOB_DEFAULT_STATE OUTPUT_HIGH_SPEED_DEF_OFF
	#define GPIOB_MINIMUM_STATE OUTPUT_HIGH_SPEED_DEF_ON

	#define GPIOC_DEFAULT_STATE OUTPUT_LOW_SPEED_DEF_OFF
	#define GPIOC_MINIMUM_STATE OUTPUT_LOW_SPEED_DEF_ON
#else
	//by default disable all pins
	#define GPIOA_DEFAULT_STATE DISABLED
	#define GPIOA_MINIMUM_STATE DISABLED

	#define GPIOB_DEFAULT_STATE DISABLED
	#define GPIOB_MINIMUM_STATE DISABLED

	#define GPIOC_DEFAULT_STATE DISABLED
	#define GPIOC_MINIMUM_STATE DISABLED
#endif

//All the settings
static setting_int pumpEnableSet = { .type=SETTINGS_TYPE_INT,
    .value=1, .minValue=0, .maxValue=1, .updated=true, .userWritable=true, .CRCchecked=false};

static setting_int powerLimitMilliwattsSet = { .type=SETTINGS_TYPE_INT,
    .value=1000, .minValue=0, .maxValue=3000, .updated=true, .userWritable=true, .CRCchecked=false};


static setting_int enableStreamModeSet = { .type=SETTINGS_TYPE_INT,
    .value=0, .minValue=0, .maxValue=MAX_STREAMING_MODE, .updated=true, .userWritable=true, .CRCchecked=false};


static setting_float measDriveVoltsSet = { .type=SETTINGS_TYPE_FLOAT,
    .value=0, .minValue=0, .maxValue=100, .updated=true, .userWritable=false, .CRCchecked=false};

static setting_float measDriveMilliampsSet = { .type=SETTINGS_TYPE_FLOAT,
    .value=0, .minValue=-5, .maxValue=1000, .updated=true, .userWritable=false, .CRCchecked=false};

static setting_float measDriveMilliwattsSet = { .type=SETTINGS_TYPE_FLOAT,
    .value=0, .minValue=-1, .maxValue=2000, .updated=true, .userWritable=false, .CRCchecked=false};

static setting_int measDriveFreqHz = { .type=SETTINGS_TYPE_INT,
    .value=21000, .minValue=18000, .maxValue=26000, 
    .updated=true, .userWritable=false, .CRCchecked=false};

static setting_float measAna1Set = { .type=SETTINGS_TYPE_FLOAT,
    .value=0, .minValue=-1000000000, .maxValue=1000000000, 
    .updated=true, .userWritable=false, .CRCchecked=false};

static setting_float measAna2Set = {  .type=SETTINGS_TYPE_FLOAT,
    .value=0, .minValue=-1000000000, .maxValue=1000000000, 
    .updated=true, .userWritable=false, .CRCchecked=false};

static setting_float measAna3Set = {  .type=SETTINGS_TYPE_FLOAT,
    .value=0, .minValue=-1000000000, .maxValue=1000000000, 
    .updated=true, .userWritable=false, .CRCchecked=false};


static setting_int modeSet = { .type=SETTINGS_TYPE_INT,
    .value=SETTINGS_MODE_MANUAL, .minValue=0, 
    .maxValue=SETTINGS_MODE_COUNT-1, .updated=true, .userWritable=true, .CRCchecked=false};


static setting_int manualModeSourceSet = { .type=SETTINGS_TYPE_INT,
    .value=DEFAULT_MANUAL_MODE_SOURCE, .minValue=0, .maxValue=SETTINGS_SOURCE_COUNT-1, 
    .updated=true, .userWritable=true, .CRCchecked=false};


static setting_int pidModeSetpointSourceSet = { .type=SETTINGS_TYPE_INT,
    .value=DEFAULT_PID_SETPOINT, .minValue=0, 
    .maxValue=SETTINGS_SOURCE_COUNT-1, .updated=true, .userWritable=true, .CRCchecked=false};

static setting_int pidModeMeasSourceSet = { .type=SETTINGS_TYPE_INT,
    .value=DEFAULT_PID_MEAS, .minValue=0, 
    .maxValue=SETTINGS_SOURCE_COUNT-1, .updated=true, .userWritable=true, .CRCchecked=false};

static setting_float pidProportionalCoeffSet = { .type=SETTINGS_TYPE_FLOAT,
    .value=5, .minValue=-99999, .maxValue=99999, 
    .updated=true, .userWritable=true, .CRCchecked=false};

static setting_float pidIntegralCoeffSet = { .type=SETTINGS_TYPE_FLOAT,
    .value=10, .minValue=-99999, .maxValue=99999, 
    .updated=true, .userWritable=true, .CRCchecked=false};

static setting_float pidIntegralLimitCoeffSet = { .type=SETTINGS_TYPE_FLOAT,
    .value=1400, .minValue=0, .maxValue=99999, 
    .updated=true, .userWritable=true, .CRCchecked=false};

static setting_float pidDifferentialCoeffSet = { .type=SETTINGS_TYPE_FLOAT,
    .value=0, .minValue=-99999, .maxValue=99999, 
    .updated=true, .userWritable=true, .CRCchecked=false};


static setting_int bangBangMeasSource = { .type=SETTINGS_TYPE_INT,
    .value=DEFAULT_BANGBANG_MEAS, .minValue=0,
    .maxValue=SETTINGS_SOURCE_COUNT-1, .updated=true, .userWritable=true, .CRCchecked=false};

static setting_float bangBangLowerThresh = { .type=SETTINGS_TYPE_FLOAT,
    .value=10, .minValue=-1000000000, .maxValue=1000000000, 
    .updated=true, .userWritable=true, .CRCchecked=false};

static setting_float bangBangUpperThresh = { .type=SETTINGS_TYPE_FLOAT,
    .value=50, .minValue=-1000000000, .maxValue=1000000000, 
    .updated=true, .userWritable=true, .CRCchecked=false};

static setting_float bangBangLowerPowerMilliwatts = { .type=SETTINGS_TYPE_FLOAT,
    .value=1000, .minValue=0, .maxValue=1400, .updated=true, .userWritable=true, .CRCchecked=false};

static setting_float bangBangUpperPowerMilliwatts = { .type=SETTINGS_TYPE_FLOAT,
    .value=0, .minValue=0, .maxValue=1400, .updated=true, .userWritable=true, .CRCchecked=false};


static setting_float setValSet = { .type=SETTINGS_TYPE_FLOAT,
    .value=250, .minValue=-1000000, .maxValue=1000000, 
    .updated=true, .userWritable=true, .CRCchecked=false};

static setting_float ana1OffsetSet = { .type=SETTINGS_TYPE_FLOAT,
    .value=0, .minValue=-99999, .maxValue=99999, 
    .updated=true, .userWritable=true, .CRCchecked=false};

static setting_float ana1GainSet = { .type=SETTINGS_TYPE_FLOAT,
    .value=1000, .minValue=-99999, .maxValue=99999, 
    .updated=true, .userWritable=true, .CRCchecked=false};

static setting_float ana2OffsetSet = { .type=SETTINGS_TYPE_FLOAT,
    .value=DEFAULT_ANA_B_OFFSET, .minValue=-99999, .maxValue=99999, 
    .updated=true, .userWritable=true, .CRCchecked=false};

static setting_float ana2GainSet = { .type=SETTINGS_TYPE_FLOAT,
    .value=2130, .minValue=-99999, .maxValue=99999, 
    .updated=true, .userWritable=true, .CRCchecked=false};

static setting_float ana3OffsetSet = { .type=SETTINGS_TYPE_FLOAT,
    .value=0, .minValue=-99999, .maxValue=99999, 
    .updated=true, .userWritable=true, .CRCchecked=false};

static setting_float ana3GainSet = { .type=SETTINGS_TYPE_FLOAT,
    .value=1000, .minValue=-99999, .maxValue=99999, 
    .updated=true, .userWritable=true, .CRCchecked=false};

static setting_int storeCurrentSettingsSet = { .type=SETTINGS_TYPE_INT,
    .value=0, .minValue=0, .maxValue=1, .updated=true, .userWritable=true, .CRCchecked=false};

static setting_int errorCode = { .type=SETTINGS_TYPE_INT,
    .value=0, .minValue=0, .maxValue=100, .updated=true, .userWritable=false, .CRCchecked=false};

static setting_float measFlowSet = {  .type=SETTINGS_TYPE_FLOAT,
    .value=0, .minValue=-2000000000, .maxValue=2000000000,
    .updated=true, .userWritable=false, .CRCchecked=false};

static setting_int resetPidOnTurnonSet = { .type=SETTINGS_TYPE_INT,
    .value=1, .minValue=0, .maxValue=1, .updated=true, .userWritable=true, .CRCchecked=false};


static setting_int useFrequencyTrackingSet = { .type=SETTINGS_TYPE_INT,
    .value=1, .minValue=0, .maxValue=1, .updated=true, .userWritable=true, .CRCchecked=false};

static setting_int manualDriveFrequencySet = { .type=SETTINGS_TYPE_INT,
    .value=21000, .minValue=19000, .maxValue=24000,
    .updated=true, .userWritable=true, .CRCchecked=false};


static setting_int firmwareVersionSet = { .type=SETTINGS_TYPE_INT,
    .value=MAJOR_FW_VERSION, .minValue=MAJOR_FW_VERSION, .maxValue=MAJOR_FW_VERSION, 
    .updated=true, .userWritable=false, .CRCchecked=false};

static setting_int firmwareTypeSet = { .type=SETTINGS_TYPE_INT,
    .value=DRIVER_TYPE, .minValue=DRIVER_TYPE, .maxValue=DRIVER_TYPE, 
    .updated=true, .userWritable=false, .CRCchecked=false};

static setting_int firmwareMinorVersionSet = { .type=SETTINGS_TYPE_INT,
    .value=MINOR_FW_VERSION, .minValue=MINOR_FW_VERSION, .maxValue=MINOR_FW_VERSION, 
    .updated=true, .userWritable=false, .CRCchecked=false};


static setting_float digitalPressureSet = { .type=SETTINGS_TYPE_FLOAT,
    .value=0, .minValue=-1000, .maxValue=3000, 
    .updated=true, .userWritable=false, .CRCchecked=false};

static setting_float digitalPressureOffsetSet = { .type=SETTINGS_TYPE_FLOAT,
    .value=0, .minValue=-100, .maxValue=100, 
    .updated=true, .userWritable=true, .CRCchecked=false};


static setting_float measDrivePhaseSet = { .type=SETTINGS_TYPE_FLOAT,
    .value=0, .minValue=-360, .maxValue=360, 
    .updated=true, .userWritable=false, .CRCchecked=false};


static setting_int driverI2cAddressSet = { .type=SETTINGS_TYPE_INT,
    .value=37, .minValue=0, .maxValue=127, 
    .updated=true, .userWritable=true, .CRCchecked=false};

static setting_int communicationInterfaceSet = { .type=SETTINGS_TYPE_INT,
    .value=1849, .minValue=1849, .maxValue=1935,
    .updated=true, .userWritable=true, .CRCchecked=true};

static setting_int pinModeGPIOASet = { .type=SETTINGS_TYPE_INT,
    .value=GPIOA_DEFAULT_STATE, .minValue=GPIOA_MINIMUM_STATE, .maxValue=GPIO_MODE_COUNT-1,
    .updated=true, .userWritable=true, .CRCchecked=false};

static setting_int pinStateGPIOASet = { .type=SETTINGS_TYPE_INT,
    .value=0, .minValue=-1, .maxValue=250,
    .updated=true, .userWritable=true, .CRCchecked=false};

static setting_int pinPulseDurationGPIOASet = { .type=SETTINGS_TYPE_INT,
    .value=0, .minValue=0, .maxValue=30000,
    .updated=true, .userWritable=true, .CRCchecked=false};

static setting_int pinPulsePeriodGPIOASet = { .type=SETTINGS_TYPE_INT,
    .value=0, .minValue=0, .maxValue=30000,
    .updated=true, .userWritable=true, .CRCchecked=false};

static setting_int pinModeGPIOBSet = { .type=SETTINGS_TYPE_INT,
    .value=GPIOB_DEFAULT_STATE, .minValue=GPIOB_MINIMUM_STATE, .maxValue=GPIO_MODE_COUNT-1,
    .updated=true, .userWritable=true, .CRCchecked=false};

static setting_int pinStateGPIOBSet = { .type=SETTINGS_TYPE_INT,
    .value=0, .minValue=-1, .maxValue=250,
    .updated=true, .userWritable=true, .CRCchecked=false};

static setting_int pinPulseDurationGPIOBSet = { .type=SETTINGS_TYPE_INT,
    .value=0, .minValue=0, .maxValue=30000,
    .updated=true, .userWritable=true, .CRCchecked=false};

static setting_int pinPulsePeriodGPIOBSet = { .type=SETTINGS_TYPE_INT,
    .value=0, .minValue=0, .maxValue=30000,
    .updated=true, .userWritable=true, .CRCchecked=false};

static setting_int pinModeGPIOCSet = { .type=SETTINGS_TYPE_INT,
    .value=GPIOC_DEFAULT_STATE, .minValue=GPIOC_MINIMUM_STATE, .maxValue=GPIO_MODE_COUNT-1,
    .updated=true, .userWritable=true, .CRCchecked=false};

static setting_int pinStateGPIOCSet = { .type=SETTINGS_TYPE_INT,
    .value=0, .minValue=-1, .maxValue=250,
    .updated=true, .userWritable=true, .CRCchecked=false};

static setting_int pinPulseDurationGPIOCSet = { .type=SETTINGS_TYPE_INT,
    .value=0, .minValue=0, .maxValue=30000,
    .updated=true, .userWritable=true, .CRCchecked=false};

static setting_int pinPulsePeriodGPIOCSet = { .type=SETTINGS_TYPE_INT,
    .value=0, .minValue=0, .maxValue=30000,
    .updated=true, .userWritable=true, .CRCchecked=false};

static setting_int pinStateGPIODSet = { .type=SETTINGS_TYPE_INT,
    .value=0, .minValue=0, .maxValue=1,
    .updated=true, .userWritable=false, .CRCchecked=false};

static setting_int LED_ColourSet = { .type=SETTINGS_TYPE_INT,
    .value=0b000001111100000, .minValue=0, .maxValue=0x7FFF,
    .updated=true, .userWritable=true, .CRCchecked=false};

static setting_int DigitalPressureMeasUnitSet = { .type=SETTINGS_TYPE_INT,
    .value=0, .minValue=0, .maxValue=6,
    .updated=true, .userWritable=true, .CRCchecked=false};

static setting_int FlowMeasUnitSet = { .type=SETTINGS_TYPE_INT,
    .value=1, .minValue=0, .maxValue=3,
    .updated=true, .userWritable=true, .CRCchecked=false};


//A struct to contain const pointers to the settings
//Other modules read values through this struct, which enforces read only access
static settings systemSettings =
{
    .pumpEnable = (const setting_int*) &pumpEnableSet,
    .powerLimitMilliwatts = (const setting_int*) &powerLimitMilliwattsSet, 

    .enableStreamMode = (const setting_int*) &enableStreamModeSet,

    .measDriveVolts = (const setting_float*) &measDriveVoltsSet,
    .measDriveMilliamps = (const setting_float*) &measDriveMilliampsSet,
    .measDriveMilliwatts = (const setting_float*) &measDriveMilliwattsSet,
    .measDriveFreq = (const setting_int*) &measDriveFreqHz,
    .measAna1 = (const setting_float*) &measAna1Set,
    .measAna2 = (const setting_float*) &measAna2Set,
    .measAna3 = (const setting_float*) &measAna3Set,

    .mode = (const setting_int*) &modeSet,

    .manualModeSource = (const setting_int*) &manualModeSourceSet,

    .pidModeSetpointSource = (const setting_int*) &pidModeSetpointSourceSet,
    .pidModeMeasSource = (const setting_int*) &pidModeMeasSourceSet,
    .pidProportionalCoeff = (const setting_float*) &pidProportionalCoeffSet,
    .pidIntegralCoeff = (const setting_float*) &pidIntegralCoeffSet,
    .pidIntegralLimitCoeff = (const setting_float*) &pidIntegralLimitCoeffSet,
    .pidDifferentialCoeff = (const setting_float*) &pidDifferentialCoeffSet,

    .bangBangMeasSource = (const setting_int*) &bangBangMeasSource,
    .bangBangLowerThresh = (const setting_float*) &bangBangLowerThresh,
    .bangBangUpperThresh = (const setting_float*) &bangBangUpperThresh,
    .bangBangLowerPowerMilliwatts = (const setting_float*) 
                                        &bangBangLowerPowerMilliwatts,
    .bangBangUpperPowerMilliwatts = (const setting_float*) 
                                        &bangBangUpperPowerMilliwatts,

    .setVal = (const setting_float*) &setValSet,
    .ana1Offset = (const setting_float*) &ana1OffsetSet,
    .ana1Gain = (const setting_float*) &ana1GainSet,
    .ana2Offset = (const setting_float*) &ana2OffsetSet,
    .ana2Gain = (const setting_float*) &ana2GainSet,
    .ana3Offset = (const setting_float*) &ana3OffsetSet,
    .ana3Gain = (const setting_float*) &ana3GainSet,

    .storeCurrentSettings = (const setting_int*) &storeCurrentSettingsSet,

    .errorCode = (const setting_int*) &errorCode,

    .measFlow = (const setting_float*) &measFlowSet,

    .resetPidOnTurnon = (const setting_int*) &resetPidOnTurnonSet,

    .useFrequencyTracking = (const setting_int*) &useFrequencyTrackingSet,
    .manualDriveFrequency = (const setting_int*) &manualDriveFrequencySet,

    .firmwareVersion = (const setting_int*) &firmwareVersionSet,
    .firmwareType = (const setting_int*) &firmwareTypeSet,
    .firmwareMinorVersion = (const setting_int*) &firmwareMinorVersionSet,

    .digitalPressure = (const setting_float*) &digitalPressureSet,
    .digitalPressureOffset = (const setting_float*) &digitalPressureOffsetSet,

    .measDrivePhase = (const setting_float*) &measDrivePhaseSet,

    .driverI2cAddress = (const setting_int*) &driverI2cAddressSet,
	.communicationInterface = (const setting_int*) &communicationInterfaceSet,
	.pinModeGPIOA = (const setting_int*) &pinModeGPIOASet,
	.pinStateGPIOA = (const setting_int*) &pinStateGPIOASet,
	.pinPulseDurationGPIOA = (const setting_int*) &pinPulseDurationGPIOASet,
	.pinPulsePeriodGPIOA = (const setting_int*) &pinPulsePeriodGPIOASet,
	.pinModeGPIOB = (const setting_int*) &pinModeGPIOBSet,
	.pinStateGPIOB = (const setting_int*) &pinStateGPIOBSet,
	.pinPulseDurationGPIOB = (const setting_int*) &pinPulseDurationGPIOBSet,
	.pinPulsePeriodGPIOB = (const setting_int*) &pinPulsePeriodGPIOBSet,
	.pinModeGPIOC = (const setting_int*) &pinModeGPIOCSet,
	.pinStateGPIOC = (const setting_int*) &pinStateGPIOCSet,
	.pinPulseDurationGPIOC = (const setting_int*) &pinPulseDurationGPIOCSet,
	.pinPulsePeriodGPIOC = (const setting_int*) &pinPulsePeriodGPIOCSet,
	.pinStateGPIOD = (const setting_int*) &pinStateGPIODSet,

	.LED_Colour = (const setting_int*) &LED_ColourSet,
	.DigitalPressureMeasUnit = (const setting_int*) &DigitalPressureMeasUnitSet,
	.FlowMeasUnit = (const setting_int*) &FlowMeasUnitSet
};

bool settings_checkCRC(uint8_t settingIdx, uint16_t valueToDecode);


settings* settings_getHandle()
{
    return &systemSettings;
}

bool settings_writeInt(const setting_int* setting, int newVal)
{
    if(setting->minValue > newVal || setting->maxValue < newVal || setting->CRCchecked)
    {
        return false;
    }

    setting_int* set = (setting_int*) setting;
    set->value = newVal;
    set->updated = true;

    return true;
}

//special function for writing to CRC protected settings
bool settings_writeCRCInt(const setting_int* setting, int newVal, uint8_t idx)
{
	if(setting->CRCchecked == false)
	{
		return false;
	}


	if(settings_checkCRC(idx, newVal) == false) return false;

	if(setting->minValue > newVal || setting->maxValue < newVal)
	{
		return false;
	}

	setting_int* set = (setting_int*) setting;
	set->value = newVal;
	set->updated = true;

	return true;
}


bool settings_writeFloat(const setting_float* setting, float newVal)
{
    if(setting->minValue > newVal || setting->maxValue < newVal || setting->CRCchecked)
    {
        return false;
    }

    setting_float* set = (setting_float*) setting;
    set->value = newVal;
    set->updated = true;

    return true;
}

void settings_updateNotedInt(const setting_int* setting)
{
    ((setting_int*) setting)->updated = false;
}

void settings_updateNotedFloat(const setting_float* setting)
{
    ((setting_float*) setting)->updated = false;
}

uint16_t settings_getSettingsCount()
{
    return sizeof(settings)/sizeof(void*);
}

settings_type settings_getTypeForSetting(uint16_t settingIdx)
{
    //Return invalid if the index is out of bounds
    if(settingIdx >= settings_getSettingsCount())
    {
        return SETTINGS_TYPE_INVALID;
    }

    void** settings = (void**)&systemSettings;
    void* settingPtr = settings[settingIdx];

    return *((settings_type*)settingPtr);
}

setting_int* settings_getSettingInt(uint16_t settingIdx)
{
    //Return a null pointer if out of bounds,
    //or not a in type setting
    if(settingIdx >= settings_getSettingsCount() ||
       settings_getTypeForSetting(settingIdx) != SETTINGS_TYPE_INT)
    {
        return 0;
    }

    void** settings = (void**)&systemSettings;

    return (setting_int*)settings[settingIdx];
}

setting_float* settings_getSettingFloat(uint16_t settingIdx)
{
    //Return a null pointer if out of bounds
    //or not a float type setting
    if(settingIdx >= settings_getSettingsCount() ||
       settings_getTypeForSetting(settingIdx) != SETTINGS_TYPE_FLOAT)
    {
        return 0;
    }

    void** settings = (void**)&systemSettings;

    return (setting_float*)settings[settingIdx];
}


bool settings_getSettingAsString(uint8_t settingIdx,
                                 uint8_t* settingStr, 
                                 uint8_t* settingStrLen)
{
    switch(settings_getTypeForSetting(settingIdx))
    {
        case SETTINGS_TYPE_INT:
            stringHandler_intAsString(settings_getSettingInt(settingIdx)->value,
                                      settingStr,
                                      settingStrLen);
            break;

        case SETTINGS_TYPE_FLOAT:
            stringHandler_floatAsString(
                    settings_getSettingFloat(settingIdx)->value,
                    settingStr,
                    settingStrLen);
            break;

        case SETTINGS_TYPE_INVALID:
            return false;
    }

    return true;
}

bool settings_setSettingAsString(uint8_t settingIdx,
                                 uint8_t* settingStr, 
                                 uint8_t settingStrLen)
{
    int32_t val_int;
    float val_float;

    switch(settings_getTypeForSetting(settingIdx))
    {
        case SETTINGS_TYPE_INT:
        {
            setting_int* setInt = settings_getSettingInt(settingIdx);

            if(!setInt->userWritable)
                return false;

            if(!stringHandler_stringAsInt(&val_int, settingStr, settingStrLen))
                return false;

            if(settings_getCRCcheckedForSetting(settingIdx))
            	return settings_writeCRCInt(setInt, val_int, settingIdx);

            return settings_writeInt(setInt, val_int);
        }

        case SETTINGS_TYPE_FLOAT:
        {
            setting_float* setFloat = settings_getSettingFloat(settingIdx);

            if(!setFloat->userWritable)
                return false;

            if(!stringHandler_stringAsFloat(&val_float, 
                                            settingStr, 
                                            settingStrLen))
            {
                return false;
            }

            return settings_writeFloat(setFloat, val_float);
        }

        case SETTINGS_TYPE_INVALID:
            return false;
    }

    return true;
}

bool settings_getCRCcheckedForSetting(uint8_t settingIdx)
{
	//Return a false pointer if out of bounds,
	//or not a int type setting
	if(settingIdx >= settings_getSettingsCount() ||
	   settings_getTypeForSetting(settingIdx) != SETTINGS_TYPE_INT)
	{
		return false;
	}
	void** settings = (void**)&systemSettings;
	return ((setting_int*)settings[settingIdx])->CRCchecked;
}

uint16_t settings_generateCRCcheck(uint8_t settingIdx, uint16_t value)
{
	return settingIdx*settingIdx + settingIdx*value;
}

bool settings_checkCRC(uint8_t settingIdx, uint16_t valueToDecode)
{
	uint16_t temp = (valueToDecode - settingIdx*settingIdx) / settingIdx;

	if (settings_generateCRCcheck(settingIdx, temp) != valueToDecode) return false;

	return true;
}
