/*
 * Copyright (C) LEE Ventus - All Rights Reserved
 * Unauthorised copying of this file, via any medium is strictly prohibited
 * Proprietary and confidential
 */
#include "sineWaveGen.h"
#include "math.h"

#define LOOKUP_SIZE_POWER (7)
#define LOOKUP_SIZE (1 << LOOKUP_SIZE_POWER)
#define LOOKUP_STEP_SHIFT (32 - LOOKUP_SIZE_POWER)

static sineWaveGen_sample lookup[LOOKUP_SIZE];

static uint32_t sampleRate;
static uint32_t countStepSize;
static uint32_t count = 0;

void sineWaveGen_init(uint8_t timerPeriod, 
                      uint8_t deadTime, 
                      uint32_t sampleRateHz)
{
    sampleRate = sampleRateHz;

    for(int lookupIdx=0; lookupIdx<LOOKUP_SIZE; lookupIdx++)
    {
        int val = sinf(lookupIdx * 3.14159 * 2.0 / LOOKUP_SIZE) * 
                  (timerPeriod - deadTime + 0.5);

        if(val > 0)
        {
            lookup[lookupIdx].highA = val;
            lookup[lookupIdx].lowA = val + deadTime;

            lookup[lookupIdx].highB = 0;
            lookup[lookupIdx].lowB = deadTime;
        }
        else
        {
            lookup[lookupIdx].highB = -val;
            lookup[lookupIdx].lowB = -val + deadTime;

            lookup[lookupIdx].highA = 0;
            lookup[lookupIdx].lowA = deadTime;
        }
    }

    sineWaveGen_setFrequencyHz(20000);
}

void sineWaveGen_setFrequencyHz(uint16_t freqHz)
{
    countStepSize = ((uint64_t)freqHz << 32) / sampleRate;
}

void sineWaveGen_getBlock(sineWaveGen_sample* samples, uint8_t sampleCount)
{
    for(uint8_t idx=0; idx<sampleCount; idx++)
    {
        count += countStepSize;

        // Since sineWaveGen_sample is 4x uint8_t it can be treated as
        // a single uint32_t. The GCC compiler didn't appear to realise this, 
        // regardless of the optimisation flag selected, and was calling memcpy.
        // The cast to (uint32_t*) reduced the time to run this function by 7x
        ((uint32_t*)samples)[idx] = 
            ((uint32_t*)lookup)[count >> LOOKUP_STEP_SHIFT];
    }
}

