/*
 * Copyright (C) LEE Ventus - All Rights Reserved
 * Unauthorised copying of this file, via any medium is strictly prohibited
 * Proprietary and confidential
 */
#ifndef UARTHANDLER_H
#define UARTHANDLER_H

#include <stdbool.h>
#include <stdint.h>

typedef struct uartHandler_setup
{
    // Function should accept a setting index, 
    // and write out the setting as a string to settingStr, 
    // and length to settingStrLen
    bool (*getSetting)(uint8_t settingIdx, 
                       uint8_t* settingStr, uint8_t* len);

    // Function should accept a settingIdx, settingStr, len (settingStr length), 
    // and return success if written, false if not
    bool (*setSetting)(uint8_t settingIdx, 
                       uint8_t* settingStr, uint8_t len);

    uint8_t* settingsToStream;  // A list of settings to send in streaming mode
    uint8_t settingsToStreamCount;  // Length of the settings to be streamed
    uint8_t ticksPerStream;  // Number of ticks between streaming update

    // Function should fill the pointer with any unread bytes, 
    // and set the length, return false if no bytes available
    bool (*getUnreadBytes)(uint8_t* unreadBytes, uint8_t* len);

    // Send bytes out, should return True on success, False if it couldn't
    // send this time
    bool (*sendBytes)(uint8_t* bytesToWrite, uint16_t len);
} uartHandler_setup;


// Called to setup the uart handler
void uartHandler_init(uartHandler_setup setupDetails);

// Call regularly to tick the handler
void uartHandler_tick();

// Call to turn streaming off or on
void uartHandler_setStreaming(bool enabled);

// Call to send a debug string
// Appends #D_ to the start of the string, before sending over the UART
void uartHandler_sendDebug(uint8_t* debugString, 
                           uint8_t debugStringLen);

#endif // UARTHANDLER_H
