/*
 * Copyright (C) LEE Ventus - All Rights Reserved
 * Unauthorised copying of this file, via any medium is strictly prohibited
 * Proprietary and confidential
 */

#include "settingsStorage.h"
#include "settings.h"
#include "stm32g0xx_hal.h"

void settingsStorage_SaveCurrentSettings()
{
    HAL_FLASH_Unlock();

    //Clear flash flags
    __HAL_FLASH_CLEAR_FLAG(FLASH_FLAG_EOP | 
                           FLASH_FLAG_WRPERR | 
                           FLASH_FLAG_PGAERR);

    //Erase the page
    FLASH_PageErase(FLASH_BANK_1, SETTINGS_STORAGE_FLASH_PAGE);
    FLASH_WaitForLastOperation(1000);

    CLEAR_BIT(FLASH->CR, FLASH_CR_PER); //Bug in the HAL means you can't
                                        //write to the flash till this bit
                                        //is cleared. Which is set by 
                                        //FLASH_PageErase above

    for(int i=0; i<settings_getSettingsCount(); i++)
    {
        settings_type type = settings_getTypeForSetting(i);

        if(type == SETTINGS_TYPE_INT)
        {
            setting_int* setting = settings_getSettingInt(i);
            int32_t data = setting->value;
            uint32_t* dataPtr = (uint32_t*) &data;

            HAL_FLASH_Program(FLASH_TYPEPROGRAM_DOUBLEWORD,
                              SETTINGS_STORAGE_FLASH_PAGE_ADDRESS + i*8,
                              *dataPtr);
        }
        else if(type == SETTINGS_TYPE_FLOAT)
        {
            setting_float* setting = settings_getSettingFloat(i);
            float data = setting->value;
            uint32_t* dataPtr = (uint32_t*) &data;

            HAL_FLASH_Program(FLASH_TYPEPROGRAM_DOUBLEWORD,
                              SETTINGS_STORAGE_FLASH_PAGE_ADDRESS + i*8,
                              *dataPtr);
        }

        FLASH_WaitForLastOperation(1000);
    }

    HAL_FLASH_Program(FLASH_TYPEPROGRAM_DOUBLEWORD,
                      SETTINGS_STORAGE_FLASH_PAGE_ADDRESS + 
                      settings_getSettingsCount() * 8,
                      SETTINGS_STORAGE_FLASH_VALID_CODE);

    FLASH_WaitForLastOperation(1000);

    HAL_FLASH_Lock();
}

void settingsStorage_RestoreSavedSettings()
{
    int32_t validCode = *(((int32_t*)SETTINGS_STORAGE_FLASH_PAGE_ADDRESS) +
                          settings_getSettingsCount()*2);

    if(validCode != SETTINGS_STORAGE_FLASH_VALID_CODE)
    {
        //Return if settings haven't been written to flash
        return;
    }

    for(int i=0; i<settings_getSettingsCount(); i++)
    {
        settings_type type = settings_getTypeForSetting(i);

        if(type == SETTINGS_TYPE_INT)
        {
            int32_t val = *((int32_t*)
                            (SETTINGS_STORAGE_FLASH_PAGE_ADDRESS + i*8));
            setting_int* setting = settings_getSettingInt(i);
            settings_writeInt(setting, val);
        }
        else if(type == SETTINGS_TYPE_FLOAT)
        {
            float val = *((float*)
                          (SETTINGS_STORAGE_FLASH_PAGE_ADDRESS + i*8));
            setting_float* setting = settings_getSettingFloat(i);
            settings_writeFloat(setting, val);
        }
    }
}


